@@ -80,18 +80,22 @@ class App(Gtk.Application, TimerManager):
 		self.config = Configuration()
 		self.process = None
 		self.hide_window = self.config["minimize_on_start"]
+		self.show_status_icon = True
 		self.exit_after_wizard = False
 		self.last_restart_time = 0.0
 		# Can be changed by --force-update=vX.Y.Z argument
 		self.force_update_version = None
 		# Determine if header bar should be shown
 		# User setting is not visible under Unity/Gnome
-		self.use_headerbar = \
-			not IS_UNITY and (not self.config["use_old_header"] or IS_GNOME) \
-			and (Gtk.get_major_version(), Gtk.get_minor_version()) >= (3, 10)
+		self.use_headerbar = (
+			not IS_UNITY and (not self.config["use_old_header"] or IS_GNOME)
+			and (Gtk.get_major_version(), Gtk.get_minor_version()) >= (3, 10) )
 		
 		self.watcher = None
 		self.daemon = None	# Created by setup_connection method
+		# If enabled (by -o argument), daemon output is captured and printed
+		# to stdout
+		self.dump_daemon_output = None
 		self.notifications = None
 		# connect_dialog may be displayed durring initial communication
 		# or if daemon shuts down.
@@ -132,6 +136,8 @@ class App(Gtk.Application, TimerManager):
 		if is_option("header"): self.use_headerbar = False
 		if is_option("window"): self.hide_window = False
 		if is_option("minimized"): self.hide_window = True
+		if is_option("dump"): self.dump_daemon_output = True
+		if is_option("no-status-icon"): self.show_status_icon = False
 		if is_option("wizard"):
 			self.exit_after_wizard = True
 			self.show_wizard()
@@ -237,12 +243,14 @@ class App(Gtk.Application, TimerManager):
 		aso("debug",	b"d", "Be more verbose (debug mode)")
 		aso("wizard",	b"1", "Run 'first start wizard' and exit")
 		aso("about",	b"a", "Display about dialog and exit")
+		aso("dump",		b"o", "Redirect captured daemon output to stdout")
 		aso("home", 0, "Overrides default syncthing configuration directory",
 				GLib.OptionArg.STRING)
 		aso("add-repo", 0,    "Opens 'add repository' dialog with specified path prefilled",
 				GLib.OptionArg.STRING)
 		aso("remove-repo", 0, "If there is repository assigned with specified path, opens 'remove repository' dialog",
 				GLib.OptionArg.STRING)
+		aso("no-status-icon", 0, "Don't show a tray status icon")
 		if not StDownloader is None:
 			aso("force-update", 0,
 					"Force updater to download specific daemon version",
@@ -314,7 +322,11 @@ class App(Gtk.Application, TimerManager):
 		self.add_window(self["window"])
 	
 	def setup_statusicon(self):
-		self.statusicon = get_status_icon(self.iconpath, self["si-menu"])
+		if self.show_status_icon:
+			self.statusicon = get_status_icon(self.iconpath, self["si-menu"])
+		else:
+			self.statusicon = statusicon.StatusIconDummy(self.iconpath, self["si-menu"])
+		
 		self.statusicon.connect("clicked",        self.cb_statusicon_click)
 		self.statusicon.connect("notify::active", self.cb_statusicon_notify_active)
 		self.cb_statusicon_notify_active()
@@ -429,6 +441,8 @@ class App(Gtk.Application, TimerManager):
 		self.process = DaemonProcess(cmdline, self.config["daemon_priority"], self.config["max_cpus"], env=vars)
 		self.process.connect('failed', self.cb_daemon_startup_failed)
 		self.process.connect('exit', self.cb_daemon_exit)
+		if self.dump_daemon_output:
+			self.process.connect('line', self.cb_daemon_line_captured)
 		self.process.start()
 	
 	def ask_for_ur(self, *a):
@@ -1092,10 +1106,11 @@ class App(Gtk.Application, TimerManager):
 			# Already animating
 			return
 		self.statusicon.set("si-%s-%s" % (self.config['icon_theme'], self.sync_animation,))
-		self.sync_animation += 1
-		if self.sync_animation >= SI_FRAMES:
-			self.sync_animation = 0
-		self.timer("icon", 0.1, self.animate_status)
+		if self.config["animate_icon"]:
+			self.sync_animation += 1
+			if self.sync_animation >= SI_FRAMES:
+				self.sync_animation = 0
+			self.timer("icon", 0.1, self.animate_status)
 	
 	def update_folders(self):
 		"""
@@ -1632,6 +1647,30 @@ class App(Gtk.Application, TimerManager):
 		else:
 			handler_id = self.daemon.connect("config-loaded", have_config)
 	
+	def get_local_device(self):
+		"""
+		Returns box with local device data.
+		May return None if connection to daemon is yet to be made or local
+		device info is not yet known.
+		"""
+		if self.daemon.get_my_id() in self.devices:
+			return self.devices[self.daemon.get_my_id()]
+		return None
+	
+	def get_local_name(self):
+		"""
+		Returns name of local device.
+		If connection to daemon is yet to be made or local device info is not
+		yet known, returns local hostname.
+		"""
+		ld = self.get_local_device()
+		if ld:
+			return ld.get_title()
+		if "HOSTNAME" in os.environ:
+			return os.environ["HOSTNAME"]
+		# Fallbacks to "local" when 
+		return "local"
+	
 	# --- Callbacks ---
 	def cb_exit(self, *a):
 		self.statusicon.hide()
@@ -1775,9 +1814,10 @@ class App(Gtk.Application, TimerManager):
 		""" Handler for 'browse' action """
 		path = os.path.expanduser(box["path"])
 		if IS_WINDOWS:
-			# Don't attempt anything, use Windows Explorer on Windows
+			# Don't attempt anything, use registry settigns on Windows
+			# (defaults to Windows Explorer)
 			path = path.replace("/", "\\")
-			os.startfile(path, 'explore')
+			os.startfile(path, self.config["file_browser"])
 		else:
 			# Try to use any of following, known commands to
 			# display directory contents
@@ -2012,6 +2052,11 @@ class App(Gtk.Application, TimerManager):
 		else:
 			self.quit()
 	
+	
+	def cb_daemon_line_captured(self, daemon, line):
+		print line
+	
+	
 	def cb_daemon_exit(self, proc, error_code):
 		if proc == self.process:
 			# Whatever happens, if daemon dies while it shouldn't,
