@@ -15,7 +15,7 @@ from gi.repository import GObject
 from gi.repository import GLib
 from gi.repository import Gtk
 
-from syncthing_gtk.tools import IS_UNITY, IS_KDE, IS_CINNAMON
+from syncthing_gtk.tools import IS_UNITY, IS_KDE, IS_CINNAMON, IS_LXQT
 from syncthing_gtk.tools import _ # gettext function
 
 log = logging.getLogger("StatusIcon")
@@ -244,7 +244,9 @@ class StatusIconGTK3(StatusIcon):
 		
 		# An invisible tray icon will never be embedded but it also should not be replaced
 		# by a fallback icon
-		is_embedded = self._tray.is_embedded() or not self._tray.get_visible() or IS_CINNAMON
+		is_embedded = self._tray.is_embedded() or not self._tray.get_visible()
+		# On some desktops, above check fails but tray is always visible
+		is_embedded = is_embedded or IS_LXQT or IS_CINNAMON
 		if is_embedded != self.get_property("active"):
 			self.set_property("active", is_embedded)
 	
