@@ -16,7 +16,8 @@ log = logging.getLogger("tools.py")
 
 IS_WINDOWS	= sys.platform in ('win32', 'win64')
 IS_XP = IS_WINDOWS and platform.release() in ("XP", "2000", "2003")
-IS_GNOME, IS_UNITY, IS_KDE, IS_CINNAMON, IS_XFCE, IS_MATE, IS_I3 = [False] * 7
+IS_GNOME, IS_UNITY, IS_KDE, IS_CINNAMON = [False] * 4
+IS_XFCE, IS_MATE, IS_I3, IS_LXQT = [False] * 4
 
 if "XDG_CURRENT_DESKTOP" in os.environ:
 	desktops = os.environ["XDG_CURRENT_DESKTOP"].split(":")
@@ -28,6 +29,7 @@ if "XDG_CURRENT_DESKTOP" in os.environ:
 	IS_MATE = ("MATE" in desktops)
 	IS_XFCE = ("XFCE" in desktops)
 	IS_I3 = ("i3" in desktops)
+	IS_LXQT = ("LXQt" in desktops)
 if "DESKTOP_SESSION" in os.environ:
 	if os.environ["DESKTOP_SESSION"] == "gnome":
 		# Fedora...
